@@ -132,7 +132,7 @@ def rdf_online(eis_data,cycling_data,n_estimators, max_features, max_depth,test_
     X_dev, X_test, y_dev, y_test = train_test_split(X, y, test_size= test_size, random_state=42)
     model.fit(X_dev, y_dev)
     
-    r2=model.score(X_test,y_test)
+    r2=r2_score(np.transpose(y_test), np.transpose(model.predict(X_test)))
     features= ml_features(eis_data,cycling_data)
     cap_ret=model.predict(features)
     err=average_err_per_cyc(y_test,model.predict(X_test))
@@ -151,17 +151,20 @@ def battery_clf(eis_data,cycling_data):
     rdf_pred=rdf.predict(X_features)
     nn_pred=nn.predict(X_features)
     gdb_pred=gdb.predict(X_features)
-    average_error= 0.15
+    gb_err=0.47
+    rdf_err=0.44
+    nn_err=0.77
+    average_error= np.mean(gb_err+rdf_err+nn_err)
     result = np.mean([rdf_pred[0][299],nn_pred[0][299],gdb_pred[0]])
-    if (result-average_error)<93:
+    if (result-average_error)<90:
         return('Bad Cell',round(result,2),average_error)
-    if (result-average_error)>98:
+    if (result-average_error)=>96:
         return('Top Graded Cell',round(result,2),average_error)
-    if 97<(result-average_error)<98:
+    if 94<=(result-average_error)<96:
         return('A',round(result,2),average_error)
-    if 95<(result-average_error)<97:
+    if 92<=(result-average_error)<94:
         return('B',round(result,2),average_error)
-    if 93<(result-average_error)<97:
+    if 90<=(result-average_error)<92:
         return('C',round(result,2),average_error)
 
 
@@ -191,11 +194,12 @@ def gbr_online(eis_data,cycling_data,n_estimators, max_depth, learning_rate,test
     
     features= ml_features(eis_data,cycling_data)
     cap_ret=model.predict(features)
-    r2=model.score(X_test,y_test)
+    r2=r2_score(np.transpose(y_test), np.transpose(model.predict(X_test)))
+    
     err=average_error(y_test,model.predict(X_test))
 
 
-    return (round(cap_ret,2),round(r2,2),round(err,2))
+    return (round(cap_ret[0],2),round(r2,2),round(err,2))
 
     
 def RMSE_per_cycle(y_pred, y_act):
@@ -240,7 +244,7 @@ def rdf_online_plot(eis_data,cycling_data,n_estimators, max_features, max_depth,
     X_dev, X_test, y_dev, y_test = train_test_split(X, y, test_size= test_size, random_state=42)
     model.fit(X_dev, y_dev)
     
-    r2=model.score(X_test,y_test)
+    r2=r2_score(np.transpose(y_test), np.transpose(model.predict(X_test)))
     features= ml_features(eis_data,cycling_data)
     
     
@@ -454,7 +458,8 @@ def rdf_online_st(eis_data,cycling_data,n_estimators, max_features, max_depth,te
     X_dev, X_test, y_dev, y_test = train_test_split(X, y, test_size= test_size, random_state=42)
     model.fit(X_dev, y_dev)
     
-    r2=model.score(X_test,y_test)
+    r2=r2_score(np.transpose(y_test), np.transpose(model.predict(X_test)))
+    
     features= ml_features(eis_data,cycling_data)
     
     
@@ -468,7 +473,7 @@ def rdf_online_st(eis_data,cycling_data,n_estimators, max_features, max_depth,te
     cycles = np.array(np.linspace(1,len(cap_ret[0]),len(cap_ret[0])))
 
 
-    fig=plt.plot(cap_ret[0], color = 'blue',label='Prediction')
+    ax=plt.plot(cap_ret[0], color = 'blue',label='Prediction')
     
     plt.fill_between(cycles,
                  np.array(cap_ret[0]+err),
@@ -571,7 +576,7 @@ def cap_ret_online_NN_st(eis_data,cycling_data, hidden_layers_sizes, learning_ra
     cycles = np.array(np.linspace(1,len(cap_ret_pred[0]),len(cap_ret_pred[0])))
 
 
-    fig=plt.plot(cap_ret_pred[0], color = 'blue',label='Prediction')
+    ax=plt.plot(cap_ret_pred[0], color = 'blue',label='Prediction')
     
     plt.fill_between(cycles,
                  np.array(cap_ret_pred[0]+err),
@@ -584,7 +589,7 @@ def cap_ret_online_NN_st(eis_data,cycling_data, hidden_layers_sizes, learning_ra
     plt.legend(loc='lower left')
     plt.show()
 
-    return (fig, round(cap_ret_pred[0][cyc_num-1],2),round(err[cyc_num-1]*rel_err,2))
+    return (fig, round(cap_ret_pred[0][cyc_num-1],2),round(err[cyc_num-1],2))
 
     
     
